@@ -117,7 +117,7 @@ AkonadiIndexingAgent::~AkonadiIndexingAgent()
 
 void AkonadiIndexingAgent::reindexAll()
 {
-    //qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Reindexing everything";
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Reindexing everything";
     m_scheduler.abort();
     m_index.removeDatabase();
     m_index.createIndexers();
@@ -126,11 +126,18 @@ void AkonadiIndexingAgent::reindexAll()
 
 void AkonadiIndexingAgent::reindexCollection(const qlonglong id)
 {
-
-    //qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Reindexing collection " << id;
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Reindexing collection " << id;
     m_scheduler.scheduleCollection(Akonadi::Collection(id), true);
 }
 
+void AkonadiIndexingAgent::reindexCollections(const QList<qlonglong> &ids)
+{
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Reindexing collections " << ids;
+    Q_FOREACH(qlonglong id, ids) {
+        m_scheduler.scheduleCollection(Akonadi::Collection(id), true);
+    }
+}
+
 qlonglong AkonadiIndexingAgent::indexedItems(const qlonglong id)
 {
     return m_index.indexedItems(id);
@@ -186,6 +193,7 @@ void AkonadiIndexingAgent::itemsMoved(const Akonadi::Item::List &items,
 void AkonadiIndexingAgent::collectionAdded(const Akonadi::Collection &collection,
                                            const Akonadi::Collection &parent)
 {
+    Q_UNUSED(parent);
     m_index.index(collection);
     m_index.scheduleCommit();
 }
@@ -222,6 +230,9 @@ void AkonadiIndexingAgent::collectionMoved(const Akonadi::Collection &collection
                                            const Akonadi::Collection &collectionSource,
                                            const Akonadi::Collection &collectionDestination)
 {
+    Q_UNUSED(collectionSource);
+    Q_UNUSED(collectionDestination);
+
     m_index.remove(collection);
     CollectionUpdateJob *job = new CollectionUpdateJob(m_index, collection, this);
     job->start();
@@ -233,6 +244,11 @@ void AkonadiIndexingAgent::cleanup()
     Akonadi::AgentBase::cleanup();
 }
 
+int AkonadiIndexingAgent::numberOfCollectionQueued()
+{
+    return m_scheduler.numberOfCollectionQueued();
+}
+
 void AkonadiIndexingAgent::onAbortRequested()
 {
     KConfig config(QStringLiteral("baloorc"));
